@@ -373,7 +373,7 @@ animations_are_disabled (GnomeBGCrossfade *fade)
 static void
 draw_background (GnomeBGCrossfade *fade)
 {
-	if (GDK_WINDOW_TYPE (fade->priv->window) == GDK_WINDOW_ROOT) {
+	if (gdk_window_get_window_type (fade->priv->window) == GDK_WINDOW_ROOT) {
                 XClearArea (GDK_WINDOW_XDISPLAY (fade->priv->window),
                             GDK_WINDOW_XID (fade->priv->window),
                             0, 0,
@@ -494,7 +494,7 @@ gnome_bg_crossfade_start (GnomeBGCrossfade *fade,
 	g_return_if_fail (fade->priv->fading_surface != NULL);
 	g_return_if_fail (fade->priv->end_surface != NULL);
 	g_return_if_fail (!gnome_bg_crossfade_is_started (fade));
-	g_return_if_fail (GDK_WINDOW_TYPE (window) != GDK_WINDOW_FOREIGN);
+	g_return_if_fail (gdk_window_get_window_type (window) != GDK_WINDOW_FOREIGN);
 
 	source = g_timeout_source_new (1000 / 60.0);
 	g_source_set_callback (source,
